<?xml version="1.0" ?><!DOCTYPE TS><TS language="ja" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About KeePassXC</source>
        <translation>KeePassXC について</translation>
    </message>
    <message>
        <source>About</source>
        <translation>このソフトウェアについて</translation>
    </message>
    <message>
        <source>Contributors</source>
        <translation>貢献者</translation>
    </message>
    <message>
        <source>Debug Info</source>
        <translation>デバッグ情報</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>クリップボードにコピー</translation>
    </message>
    <message>
        <source>Version %1
</source>
        <translation>バージョン %1
</translation>
    </message>
    <message>
        <source>Revision: %1</source>
        <translation>リビジョン: %1</translation>
    </message>
    <message>
        <source>Libraries:</source>
        <translation>ライブラリ:</translation>
    </message>
    <message>
        <source>Operating system: %1
CPU architecture: %2
Kernel: %3 %4</source>
        <translation>オペレーティングシステム: %1
CPU アーキテクチャ: %2
カーネル: %3 %4</translation>
    </message>
    <message>
        <source>Enabled extensions:</source>
        <translation>有効化された拡張機能:</translation>
    </message>
    <message>
        <source>Report bugs at: &lt;a href=&quot;https://github.com/keepassxreboot/keepassxc/issues&quot; style=&quot;text-decoration: underline;&quot;&gt;https://github.com&lt;/a&gt;</source>
        <translation>バグ報告先: &lt;a href=&quot;https://github.com/keepassxreboot/keepassxc/issues&quot; style=&quot;text-decoration: underline;&quot;&gt;https://github.com&lt;/a&gt;</translation>
    </message>
    <message>
        <source>KeePassXC is distributed under the terms of the GNU General Public License (GPL) version 2 or (at your option) version 3.</source>
        <translation>KeePassXC は GNU General Public License (GPL) version 2 または version 3 (どちらかを選択)の条件で配布されます。</translation>
    </message>
    <message>
        <source>Project Maintainers:</source>
        <translation>プロジェクトメンテナ:</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;https://github.com/keepassxreboot/keepassxc/graphs/contributors&quot;&gt;See Contributions on GitHub&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;https://github.com/keepassxreboot/keepassxc/graphs/contributors&quot;&gt;GitHub で貢献を確認する&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Include the following information whenever you report a bug:</source>
        <translation>バグを報告する際に下記の情報を含めてください:</translation>
    </message>
    <message>
        <source>Distribution: %1</source>
        <translation>配布形式: %1</translation>
    </message>
</context>
<context>
    <name>AccessControlDialog</name>
    <message>
        <source>Remember this decision</source>
        <translation>この決定を記憶する</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>許可</translation>
    </message>
    <message>
        <source>Deny</source>
        <translation>拒否</translation>
    </message>
    <message>
        <source>%1 has requested access to passwords for the following item(s).
Please select whether you want to allow access.</source>
        <translation>%1 が以下の項目のパスワードへのアクセスを要求しました。
アクセスを許可するかどうかを選択してください。</translation>
    </message>
    <message>
        <source>KeePassXC HTTP Confirm Access</source>
        <translation>KeePassXC HTTP アクセス確認</translation>
    </message>
</context>
<context>
    <name>AutoType</name>
    <message>
        <source>Couldn&apos;t find an entry that matches the window title:</source>
        <translation>ウィンドウタイトルにマッチするエントリーが見つかりませんでした:</translation>
    </message>
    <message>
        <source>Auto-Type - KeePassXC</source>
        <translation>自動入力 - KeePassXC</translation>
    </message>
</context>
<context>
    <name>AutoTypeAssociationsModel</name>
    <message>
        <source>Window</source>
        <translation>ウィンドウ</translation>
    </message>
    <message>
        <source>Sequence</source>
        <translation>シーケンス</translation>
    </message>
    <message>
        <source>Default sequence</source>
        <translation>デフォルトのシーケンス</translation>
    </message>
</context>
<context>
    <name>AutoTypeSelectDialog</name>
    <message>
        <source>Select entry to Auto-Type:</source>
        <translation>自動入力するエントリーを選択してください:</translation>
    </message>
    <message>
        <source>Auto-Type - KeePassXC</source>
        <translation>自動入力 - KeePassXC</translation>
    </message>
</context>
<context>
    <name>ChangeMasterKeyWidget</name>
    <message>
        <source>Password</source>
        <translation>パスワード</translation>
    </message>
    <message>
        <source>Enter password:</source>
        <translation>パスワードを入力:</translation>
    </message>
    <message>
        <source>Repeat password:</source>
        <translation>パスワードを再入力:</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>参照</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>作成</translation>
    </message>
    <message>
        <source>Key files</source>
        <translation>キーファイル</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>全てのファイル</translation>
    </message>
    <message>
        <source>Create Key File...</source>
        <translation>キーファイルを作成...</translation>
    </message>
    <message>
        <source>Unable to create Key File : </source>
        <translation>キーファイルを作成できませんでした:</translation>
    </message>
    <message>
        <source>Select a key file</source>
        <translation>キーファイルを選択</translation>
    </message>
    <message>
        <source>Do you really want to use an empty string as password?</source>
        <translation>本当にパスワードとして空の文字列を使用しますか？</translation>
    </message>
    <message>
        <source>Different passwords supplied.</source>
        <translation>異なるパスワードが入力されました。</translation>
    </message>
    <message>
        <source>Failed to set %1 as the Key file:
%2</source>
        <translation>%1 をキーファイルとしてセットできませんでした:
%2</translation>
    </message>
    <message>
        <source>&amp;Key file</source>
        <translation>キーファイル(&amp;K)</translation>
    </message>
    <message>
        <source>Cha&amp;llenge Response</source>
        <translation>チャレンジレスポンス(&amp;L)</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>再読み込み</translation>
    </message>
    <message>
        <source>Empty password</source>
        <translation>空パスワード</translation>
    </message>
    <message>
        <source>Changing master key failed: no YubiKey inserted.</source>
        <translation>マスターキーの変更に失敗しました: YubiKey が挿入されていません。</translation>
    </message>
</context>
<context>
    <name>CloneDialog</name>
    <message>
        <source>Clone Options</source>
        <translation>複製のオプション</translation>
    </message>
    <message>
        <source>Replace username and password with references</source>
        <translation>ユーザー名とパスワードを参照で置き換える</translation>
    </message>
    <message>
        <source>Copy history</source>
        <translation>履歴をコピー</translation>
    </message>
    <message>
        <source>Append &apos; - Clone&apos; to title</source>
        <translation>タイトルに &apos; - 複製&apos; を追加</translation>
    </message>
</context>
<context>
    <name>CsvImportWidget</name>
    <message>
        <source>Import CSV fields</source>
        <translation>CSV フィールドをインポート</translation>
    </message>
    <message>
        <source>filename</source>
        <translation>ファイル名</translation>
    </message>
    <message>
        <source>size, rows, columns</source>
        <translation>サイズ、行、列</translation>
    </message>
    <message>
        <source>Encoding</source>
        <translation>エンコーディング</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>コーデック</translation>
    </message>
    <message>
        <source>Text is qualified by</source>
        <translation>テキスト修飾子</translation>
    </message>
    <message>
        <source>Fields are separated by</source>
        <translation>区切り文字</translation>
    </message>
    <message>
        <source>Comments start with</source>
        <translation>コメントの行頭</translation>
    </message>
    <message>
        <source>First record has field names</source>
        <translation>最初のレコードがフィールド名</translation>
    </message>
    <message>
        <source>Number of headers line to discard</source>
        <translation>破棄する先頭行の数</translation>
    </message>
    <message>
        <source>Consider &apos;\&apos; an escape character</source>
        <translation>エスケープ文字 &apos;\&apos; を考慮する</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>プレビュー</translation>
    </message>
    <message>
        <source>Column layout</source>
        <translation>列のレイアウト</translation>
    </message>
    <message>
        <source>Not present in CSV file</source>
        <translation>CSV ファイルには存在しません</translation>
    </message>
    <message>
        <source>Empty fieldname </source>
        <translation>空のフィールド名</translation>
    </message>
    <message>
        <source>column </source>
        <translation>列</translation>
    </message>
    <message>
        <source>Imported from CSV file</source>
        <translation>CSV ファイルからインポート</translation>
    </message>
    <message>
        <source>Original data: </source>
        <translation>元データ:</translation>
    </message>
    <message>
        <source>Error(s) detected in CSV file !</source>
        <translation>CSV ファイルでエラーが検出されました</translation>
    </message>
    <message>
        <source> more messages skipped]</source>
        <translation> 個のメッセージがスキップされました]</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <source>CSV import: writer has errors:
</source>
        <translation>CSV のインポート: ライターにエラーがあります:
</translation>
    </message>
</context>
<context>
    <name>CsvImportWizard</name>
    <message>
        <source>Import CSV file</source>
        <translation>CSV ファイルをインポート</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>マスターキーを計算できません</translation>
    </message>
</context>
<context>
    <name>CsvParserModel</name>
    <message>
        <source> byte, </source>
        <translation>バイト、</translation>
    </message>
    <message>
        <source> rows, </source>
        <translation>行、</translation>
    </message>
    <message>
        <source> columns</source>
        <translation>列</translation>
    </message>
</context>
<context>
    <name>DatabaseOpenWidget</name>
    <message>
        <source>Enter master key</source>
        <translation>マスターキーの入力</translation>
    </message>
    <message>
        <source>Key File:</source>
        <translation>キーファイル:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>パスワード:</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>参照</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>データベースを開けませんでした。</translation>
    </message>
    <message>
        <source>Can&apos;t open key file</source>
        <translation>キーファイルを開けませんでした</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>全てのファイル</translation>
    </message>
    <message>
        <source>Key files</source>
        <translation>キーファイル</translation>
    </message>
    <message>
        <source>Select key file</source>
        <translation>キーファイルを選択</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>再読み込み</translation>
    </message>
    <message>
        <source>Challenge Response:</source>
        <translation>チャレンジレスポンス:</translation>
    </message>
</context>
<context>
    <name>DatabaseRepairWidget</name>
    <message>
        <source>Repair database</source>
        <translation>データベースを修復</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <source>Can&apos;t open key file</source>
        <translation>キーファイルを開けませんでした</translation>
    </message>
    <message>
        <source>Database opened fine. Nothing to do.</source>
        <translation>データベースは正常に開かれています。行うべきことはありません。</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>データベースを開けませんでした。</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>成功</translation>
    </message>
    <message>
        <source>The database has been successfully repaired
You can now save it.</source>
        <translation>データベースは正常に修復されました
データベースの保存を行ってください。</translation>
    </message>
    <message>
        <source>Unable to repair the database.</source>
        <translation>データベースを修復できませんでした。</translation>
    </message>
</context>
<context>
    <name>DatabaseSettingsWidget</name>
    <message>
        <source>Database name:</source>
        <translation>データベース名:</translation>
    </message>
    <message>
        <source>Database description:</source>
        <translation>データベースの概要:</translation>
    </message>
    <message>
        <source>Transform rounds:</source>
        <translation>変換回数:</translation>
    </message>
    <message>
        <source>Default username:</source>
        <translation>デフォルトのユーザー名:</translation>
    </message>
    <message>
        <source> MiB</source>
        <translation> MiB</translation>
    </message>
    <message>
        <source>Benchmark</source>
        <translation>ベンチマーク</translation>
    </message>
    <message>
        <source>Max. history items:</source>
        <translation>最大履歴数:</translation>
    </message>
    <message>
        <source>Max. history size:</source>
        <translation>最大履歴データサイズ:</translation>
    </message>
    <message>
        <source>Use recycle bin</source>
        <translation>ゴミ箱を使用する</translation>
    </message>
    <message>
        <source>AES:  256 Bit   (default)</source>
        <translation>AES: 256 ビット (既定)</translation>
    </message>
    <message>
        <source>Twofish:  256 Bit</source>
        <translation>Twofish: 256 ビット</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>アルゴリズム:</translation>
    </message>
</context>
<context>
    <name>DatabaseTabWidget</name>
    <message>
        <source>Root</source>
        <translation>ルート</translation>
    </message>
    <message>
        <source>KeePass 2 Database</source>
        <translation>KeePass 2 データベース</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>全てのファイル</translation>
    </message>
    <message>
        <source>Open database</source>
        <translation>データベースを開く</translation>
    </message>
    <message>
        <source>File not found!</source>
        <translation>ファイルが見つかりません</translation>
    </message>
    <message>
        <source>Open KeePass 1 database</source>
        <translation>KeePass 1 データベースを開く</translation>
    </message>
    <message>
        <source>KeePass 1 database</source>
        <translation>KeePass 1 データベース</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>全てのファイル (*)</translation>
    </message>
    <message>
        <source>Close?</source>
        <translation>閉じますか？</translation>
    </message>
    <message>
        <source>Save changes?</source>
        <translation>変更を保存しますか？</translation>
    </message>
    <message>
        <source>&quot;%1&quot; was modified.
Save changes?</source>
        <translation>&quot;%1&quot; は編集されています。
変更を保存しますか？</translation>
    </message>
    <message>
        <source>Writing the database failed.</source>
        <translation>データベースが保存できませんでした。</translation>
    </message>
    <message>
        <source>Save database as</source>
        <translation>データベースを別名で保存</translation>
    </message>
    <message>
        <source>New database</source>
        <translation>新しいデータベース</translation>
    </message>
    <message>
        <source>locked</source>
        <translation>ロック済み</translation>
    </message>
    <message>
        <source>Lock database</source>
        <translation>データベースをロックする</translation>
    </message>
    <message>
        <source>Can't lock the database as you are currently editing it.
Please press cancel to finish your changes or discard them.</source>
        <translation>現在編集中のため、データベースをロックすることができませんでした。
キャンセルボタンを押し、変更を完了させるか破棄してください。</translation>
    </message>
    <message>
        <source>This database has never been saved.
You can save the database or stop locking it.</source>
        <translation>このデータベースは一度も保存されていません。
データベースを保存してロックを解除してください。</translation>
    </message>
    <message>
        <source>This database has been modified.
Do you want to save the database before locking it?
Otherwise your changes are lost.</source>
        <translation>このデータベースは変更されました。
ロックを行う前にデータベースを保存しますか？
保存しない場合には変更点は失われます。</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is in edit mode.
Discard changes and close anyway?</source>
        <translation>&quot;%1&quot; は現在編集モードです。
変更を破棄して閉じてしまってもよろしいですか？</translation>
    </message>
    <message>
        <source>Export database to CSV file</source>
        <translation>データベースを CSV ファイルにエクスポートする</translation>
    </message>
    <message>
        <source>CSV file</source>
        <translation>CSV ファイル</translation>
    </message>
    <message>
        <source>Writing the CSV file failed.</source>
        <translation>CSV ファイルの書き込みに失敗しました。</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>データベースを開けませんでした。</translation>
    </message>
    <message>
        <source>Merge database</source>
        <translation>データベースをマージする</translation>
    </message>
    <message>
        <source>The database you are trying to save as is locked by another instance of KeePassXC.
Do you want to save it anyway?</source>
        <translation>保存しようとしたデータベースは KeePassXC の別インスタンスによってロックされています。
強制的に保存しますか？</translation>
    </message>
    <message>
        <source>Passwords</source>
        <translation>パスワード</translation>
    </message>
    <message>
        <source>Database already opened</source>
        <translation>データベースを既に開いています</translation>
    </message>
    <message>
        <source>The database you are trying to open is locked by another instance of KeePassXC.

Do you want to open it anyway?</source>
        <translation>開こうとしたデータベースは KeePassXC の別インスタンスによってロックされています。
強制的に開きますか？</translation>
    </message>
    <message>
        <source>Open read-only</source>
        <translation>読み取り専用で開く</translation>
    </message>
    <message>
        <source>File opened in read only mode.</source>
        <translation>読み取り専用でファイルを開きました。</translation>
    </message>
    <message>
        <source>Open CSV file</source>
        <translation>CSV ファイルを開く</translation>
    </message>
</context>
<context>
    <name>DatabaseWidget</name>
    <message>
        <source>Change master key</source>
        <translation>マスターキーを変更</translation>
    </message>
    <message>
        <source>Delete entry?</source>
        <translation>エントリーを削除しますか？</translation>
    </message>
    <message>
        <source>Do you really want to delete the entry &quot;%1&quot; for good?</source>
        <translation>本当にエントリー &quot;%1&quot; を永久に削除しますか？</translation>
    </message>
    <message>
        <source>Delete entries?</source>
        <translation>エントリーを削除しますか？</translation>
    </message>
    <message>
        <source>Do you really want to delete %1 entries for good?</source>
        <translation>本当に %1 個のエントリーを永久に削除しますか？</translation>
    </message>
    <message>
        <source>Move entries to recycle bin?</source>
        <translation>エントリーをゴミ箱に移動しますか？</translation>
    </message>
    <message numerus="yes">
        <source>Do you really want to move %n entry(s) to the recycle bin?</source>
        <translation><numerusform>本当に %n 個のエントリーをゴミ箱に移動しますか？</numerusform></translation>
    </message>
    <message>
        <source>Delete group?</source>
        <translation>グループを削除しますか？</translation>
    </message>
    <message>
        <source>Do you really want to delete the group &quot;%1&quot; for good?</source>
        <translation>本当にグループ &quot;%1&quot; を永久に削除しますか？</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>マスターキーを計算できませんでした</translation>
    </message>
    <message>
        <source>Move entry to recycle bin?</source>
        <translation>エントリーをゴミ箱に移動しますか？</translation>
    </message>
    <message>
        <source>Do you really want to move entry &quot;%1&quot; to the recycle bin?</source>
        <translation>本当にエントリー &quot;%1&quot; をゴミ箱に移動しますか？</translation>
    </message>
    <message>
        <source>Searching...</source>
        <translation>検索中…</translation>
    </message>
    <message>
        <source>No current database.</source>
        <translation>現在のデータベースはありません。</translation>
    </message>
    <message>
        <source>No source database, nothing to do.</source>
        <translation>ソースデータベースはありません。行うべきことはありません。</translation>
    </message>
    <message>
        <source>Search Results (%1)</source>
        <translation>検索結果 (%1)</translation>
    </message>
    <message>
        <source>No Results</source>
        <translation>見つかりません</translation>
    </message>
    <message>
        <source>Execute command?</source>
        <translation>コマンドを実行しますか？</translation>
    </message>
    <message>
        <source>Do you really want to execute the following command?&lt;br&gt;&lt;br&gt;%1&lt;br&gt;</source>
        <translation>本当に次のコマンドを実行しますか？&lt;br&gt;&lt;br&gt;%1&lt;br&gt;</translation>
    </message>
    <message>
        <source>Remember my choice</source>
        <translation>選択を記憶する</translation>
    </message>
    <message>
        <source>Autoreload Request</source>
        <translation>自動再読み込みリクエスト</translation>
    </message>
    <message>
        <source>The database file has changed. Do you want to load the changes?</source>
        <translation>データベースファイルが変更されました。変更を読み込みますか？</translation>
    </message>
    <message>
        <source>Merge Request</source>
        <translation>マージリクエスト</translation>
    </message>
    <message>
        <source>The database file has changed and you have unsaved changes.Do you want to merge your changes?</source>
        <translation>データベースファイルが変更され、未保存の変更があります。変更をマージしますか？</translation>
    </message>
    <message>
        <source>Could not open the new database file while attempting to autoreload this database.</source>
        <translation>このデータベースを自動再読み込みしようとした際に、新しいデータベースファイルを開くことができませんでした。</translation>
    </message>
    <message>
        <source>Empty recycle bin?</source>
        <translation>ゴミ箱を空にしますか？</translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete everything from your recycle bin?</source>
        <translation>ゴミ箱にある全項目を永久に削除してもよろしいですか？</translation>
    </message>
</context>
<context>
    <name>EditEntryWidget</name>
    <message>
        <source>Entry</source>
        <translation>エントリー</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>詳細設定</translation>
    </message>
    <message>
        <source>Icon</source>
        <translation>アイコン</translation>
    </message>
    <message>
        <source>Auto-Type</source>
        <translation>自動入力</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>プロパティ</translation>
    </message>
    <message>
        <source>History</source>
        <translation>履歴</translation>
    </message>
    <message>
        <source>Entry history</source>
        <translation>エントリーの履歴</translation>
    </message>
    <message>
        <source>Add entry</source>
        <translation>エントリーを追加</translation>
    </message>
    <message>
        <source>Edit entry</source>
        <translation>エントリーを編集</translation>
    </message>
    <message>
        <source>Different passwords supplied.</source>
        <translation>異なるパスワードが入力されました。</translation>
    </message>
    <message>
        <source>New attribute</source>
        <translation>新しい属性</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation>ファイルを選択</translation>
    </message>
    <message>
        <source>Unable to open file</source>
        <translation>ファイルを開けませんでした</translation>
    </message>
    <message>
        <source>Save attachment</source>
        <translation>添付を保存</translation>
    </message>
    <message>
        <source>Unable to save the attachment:
</source>
        <translation>添付を保存できませんでした:
</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>明日</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation><numerusform>%n週間</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s)</source>
        <translation><numerusform>%nヶ月</numerusform></translation>
    </message>
    <message>
        <source>1 year</source>
        <translation>1年</translation>
    </message>
    <message>
        <source>Confirm Remove</source>
        <translation>削除の確認</translation>
    </message>
    <message>
        <source>Are you sure you want to remove this attribute?</source>
        <translation>この属性を削除してもよろしいですか？</translation>
    </message>
    <message>
        <source>[PROTECTED] Press reveal to view or edit</source>
        <translation>[保護] 表示または編集する場合は開示をクリックしてください</translation>
    </message>
    <message>
        <source>Are you sure you want to remove this attachment?</source>
        <translation>この添付を削除してもよろしいですか？</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetAdvanced</name>
    <message>
        <source>Additional attributes</source>
        <translation>追加属性</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>追加</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>削除</translation>
    </message>
    <message>
        <source>Attachments</source>
        <translation>添付ファイル</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>開く</translation>
    </message>
    <message>
        <source>Edit Name</source>
        <translation>名前を編集</translation>
    </message>
    <message>
        <source>Protect</source>
        <translation>保護</translation>
    </message>
    <message>
        <source>Reveal</source>
        <translation>開示</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetAutoType</name>
    <message>
        <source>Enable Auto-Type for this entry</source>
        <translation>このエントリーの自動入力を有効にする</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Window title:</source>
        <translation>ウィンドウタイトル:</translation>
    </message>
    <message>
        <source>Inherit default Auto-Type sequence from the &amp;group</source>
        <translation>自動入力シーケンスをグループから引き継ぐ(&amp;G)</translation>
    </message>
    <message>
        <source>&amp;Use custom Auto-Type sequence:</source>
        <translation>カスタムした自動入力シーケンスを使用する(&amp;U):</translation>
    </message>
    <message>
        <source>Use default se&amp;quence</source>
        <translation>デフォルトのシーケンスを使用する(&amp;Q)</translation>
    </message>
    <message>
        <source>Set custo&amp;m sequence:</source>
        <translation>カスタムしたシーケンスを設定する(&amp;M):</translation>
    </message>
    <message>
        <source>Window Associations</source>
        <translation>ウィンドウの関連付け</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetHistory</name>
    <message>
        <source>Show</source>
        <translation>表示</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>復元</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <source>Delete all</source>
        <translation>全て削除</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetMain</name>
    <message>
        <source>Title:</source>
        <translation>タイトル:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>ユーザー名:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>パスワード:</translation>
    </message>
    <message>
        <source>Repeat:</source>
        <translation>パスワード確認:</translation>
    </message>
    <message>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>期限</translation>
    </message>
    <message>
        <source>Presets</source>
        <translation>プリセット</translation>
    </message>
    <message>
        <source>Notes:</source>
        <translation>メモ:</translation>
    </message>
</context>
<context>
    <name>EditGroupWidget</name>
    <message>
        <source>Group</source>
        <translation>グループ</translation>
    </message>
    <message>
        <source>Icon</source>
        <translation>アイコン</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>プロパティ</translation>
    </message>
    <message>
        <source>Add group</source>
        <translation>グループを追加</translation>
    </message>
    <message>
        <source>Edit group</source>
        <translation>グループを編集</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>有効</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>無効</translation>
    </message>
    <message>
        <source>Inherit from parent group (%1)</source>
        <translation>親グループ &quot;(%1)&quot; から引き継ぐ</translation>
    </message>
</context>
<context>
    <name>EditGroupWidgetMain</name>
    <message>
        <source>Name</source>
        <translation>グループ名</translation>
    </message>
    <message>
        <source>Notes</source>
        <translation>メモ</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>期限</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>検索</translation>
    </message>
    <message>
        <source>Auto-Type</source>
        <translation>自動入力</translation>
    </message>
    <message>
        <source>&amp;Use default Auto-Type sequence of parent group</source>
        <translation>親グループのデフォルトの自動入力シーケンスを使用する(&amp;U)</translation>
    </message>
    <message>
        <source>Set default Auto-Type se&amp;quence</source>
        <translation>デフォルトの自動入力シーケンスを設定する(&amp;Q)</translation>
    </message>
</context>
<context>
    <name>EditWidgetIcons</name>
    <message>
        <source>Add custom icon</source>
        <translation>カスタムアイコンを追加</translation>
    </message>
    <message>
        <source>Delete custom icon</source>
        <translation>カスタムアイコンを削除</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>画像</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>全てのファイル</translation>
    </message>
    <message>
        <source>Select Image</source>
        <translation>画像を選択</translation>
    </message>
    <message>
        <source>Download favicon</source>
        <translation>ファビコンをダウンロード</translation>
    </message>
    <message>
        <source>Unable to fetch favicon.</source>
        <translation>ファビコンを取得できません。</translation>
    </message>
    <message>
        <source>Can&apos;t read icon</source>
        <translation>アイコンを読み取ることができません</translation>
    </message>
    <message>
        <source>&amp;Use default icon</source>
        <translation>デフォルトアイコンから選択(&amp;U)</translation>
    </message>
    <message>
        <source>Use custo&amp;m icon</source>
        <translation>カスタムアイコンから選択(&amp;M)</translation>
    </message>
    <message>
        <source>Confirm Delete</source>
        <translation>削除の確認</translation>
    </message>
    <message>
        <source>This icon is used by %1 entries, and will be replaced by the default icon. Are you sure you want to delete it?</source>
        <translation>このアイコンは %1 個のエントリーで使用されており、デフォルトのアイコンに置き換えられます。本当に削除してもよろしいですか？</translation>
    </message>
    <message>
        <source>Hint: You can enable Google as a fallback under Tools&gt;Settings&gt;Security</source>
        <translation>ヒント: ツール &gt; 設定 &gt; セキュリティから Google をフォールバックとして有効にすることができます</translation>
    </message>
    <message>
        <source>Custom icon already exists</source>
        <translation>カスタムアイコンは既に存在します</translation>
    </message>
</context>
<context>
    <name>EditWidgetProperties</name>
    <message>
        <source>Created:</source>
        <translation>作成日時:</translation>
    </message>
    <message>
        <source>Modified:</source>
        <translation>編集日時:</translation>
    </message>
    <message>
        <source>Accessed:</source>
        <translation>アクセス日時:</translation>
    </message>
    <message>
        <source>Uuid:</source>
        <translation>UUID:</translation>
    </message>
</context>
<context>
    <name>Entry</name>
    <message>
        <source> - Clone</source>
        <translation> - 複製</translation>
    </message>
</context>
<context>
    <name>EntryAttributesModel</name>
    <message>
        <source>Name</source>
        <translation>名前</translation>
    </message>
</context>
<context>
    <name>EntryHistoryModel</name>
    <message>
        <source>Last modified</source>
        <translation>最終更新日時</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>タイトル</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>ユーザー名</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
</context>
<context>
    <name>EntryModel</name>
    <message>
        <source>Group</source>
        <translation>グループ</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>タイトル</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>ユーザー名</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Ref: </source>
        <comment>Reference abbreviation</comment>
        <translation>参照:</translation>
    </message>
</context>
<context>
    <name>Group</name>
    <message>
        <source>Recycle Bin</source>
        <translation>ゴミ箱</translation>
    </message>
</context>
<context>
    <name>HttpPasswordGeneratorWidget</name>
    <message>
        <source>Length:</source>
        <translation>文字数:</translation>
    </message>
    <message>
        <source>Character Types</source>
        <translation>文字種</translation>
    </message>
    <message>
        <source>Upper Case Letters</source>
        <translation>大文字</translation>
    </message>
    <message>
        <source>A-Z</source>
        <translation>A-Z</translation>
    </message>
    <message>
        <source>Lower Case Letters</source>
        <translation>小文字</translation>
    </message>
    <message>
        <source>a-z</source>
        <translation>a-z</translation>
    </message>
    <message>
        <source>Numbers</source>
        <translation>数字</translation>
    </message>
    <message>
        <source>0-9</source>
        <translation>0-9</translation>
    </message>
    <message>
        <source>Special Characters</source>
        <translation>特殊な文字</translation>
    </message>
    <message>
        <source>/*_&amp; ...</source>
        <translation>/*_&amp; ...</translation>
    </message>
    <message>
        <source>Exclude look-alike characters</source>
        <translation>よく似た文字を除外する</translation>
    </message>
    <message>
        <source>Ensure that the password contains characters from every group</source>
        <translation>使用する文字種の文字が必ず含まれるようにする</translation>
    </message>
</context>
<context>
    <name>KMessageWidget</name>
    <message>
        <source>&amp;Close</source>
        <translation>閉じる(&amp;C)</translation>
    </message>
    <message>
        <source>Close message</source>
        <translation>メッセージを閉じる</translation>
    </message>
</context>
<context>
    <name>KeePass1OpenWidget</name>
    <message>
        <source>Import KeePass1 database</source>
        <translation>KeePass1 データベースをインポート</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>データベースを開けませんでした。</translation>
    </message>
</context>
<context>
    <name>KeePass1Reader</name>
    <message>
        <source>Unable to read keyfile.</source>
        <translation>キーファイルを読み込めませんでした。</translation>
    </message>
    <message>
        <source>Not a KeePass database.</source>
        <translation>KeePass データベースではありません。</translation>
    </message>
    <message>
        <source>Unsupported encryption algorithm.</source>
        <translation>サポートしていない暗号化アルゴリズムです。</translation>
    </message>
    <message>
        <source>Unsupported KeePass database version.</source>
        <translation>サポートしていないバージョンの KeePass データベースです。</translation>
    </message>
    <message>
        <source>Root</source>
        <translation>ルート</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>マスターキーを計算できませんでした</translation>
    </message>
    <message>
        <source>Wrong key or database file is corrupt.</source>
        <translation>キーが間違っているかデータベースファイルが破損しています。</translation>
    </message>
</context>
<context>
    <name>KeePass2Reader</name>
    <message>
        <source>Not a KeePass database.</source>
        <translation>KeePass データベースではありません。</translation>
    </message>
    <message>
        <source>Unsupported KeePass database version.</source>
        <translation>サポートしていないバージョンの KeePass データベースです。</translation>
    </message>
    <message>
        <source>Wrong key or database file is corrupt.</source>
        <translation>キーが間違っているかデータベースファイルが破損しています。</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>マスターキーを計算できません</translation>
    </message>
    <message>
        <source>Unable to issue challenge-response.</source>
        <translation>チャレンジレスポンスを発行することができません。</translation>
    </message>
    <message>
        <source>The selected file is an old KeePass 1 database (.kdb).

You can import it by clicking on Database &gt; 'Import KeePass 1 database...'.
This is a one-way migration. You won&apos;t be able to open the imported database with the old KeePassX 0.4 version.</source>
        <translation>選択されたファイルは古い KeePass 1 のデータベース (.kdb) です。

データベース &gt; &apos;KeePass 1 データベースをインポート...&apos; をクリックすることでインポートできます。
これは一方向の移行操作であり、インポートされたデータベースは古い KeePassX 0.4 のバージョンでは開くことはできません。</translation>
    </message>
</context>
<context>
    <name>KeePass2Writer</name>
    <message>
        <source>Unable to issue challenge-response.</source>
        <translation>チャレンジレスポンスを発行することができません。</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>マスターキーを計算できません</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Fatal error while testing the cryptographic functions.</source>
        <translation>暗号化機能のテスト中に致命的なエラーが発生しました。</translation>
    </message>
    <message>
        <source>KeePassXC - Error</source>
        <translation>KeePassXC - エラー</translation>
    </message>
    <message>
        <source>The lock file could not be created. Single-instance mode disabled.</source>
        <translation>ロックファイルを作成できませんでした。シングルインスタンスモードは無効です。</translation>
    </message>
    <message>
        <source>Another instance of KeePassXC is already running.</source>
        <translation>KeePassXC の別インスタンスが既に起動しています。</translation>
    </message>
    <message>
        <source>Existing single-instance lock file is invalid. Launching new instance.</source>
        <translation>既存のシングルインスタンスロックファイルは無効です。新しいインスタンスを起動します。</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Open database</source>
        <translation>データベースを開く</translation>
    </message>
    <message>
        <source>Database settings</source>
        <translation>データベースの設定</translation>
    </message>
    <message>
        <source>Copy username to clipboard</source>
        <translation>ユーザー名をコピー</translation>
    </message>
    <message>
        <source>Copy password to clipboard</source>
        <translation>パスワードをコピー</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <source>Show toolbar</source>
        <translation>ツールバーを表示</translation>
    </message>
    <message>
        <source>read-only</source>
        <translation>読み取り専用</translation>
    </message>
    <message>
        <source>Toggle window</source>
        <translation>ウィンドウ切替</translation>
    </message>
    <message>
        <source>KeePass 2 Database</source>
        <translation>KeePass 2 データベース</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>全てのファイル</translation>
    </message>
    <message>
        <source>Save repaired database</source>
        <translation>修復されたデータベースを保存する</translation>
    </message>
    <message>
        <source>Writing the database failed.</source>
        <translation>データベースの書き込みに失敗しました。</translation>
    </message>
    <message>
        <source>&amp;Recent databases</source>
        <translation>最近使用したデータベース(&amp;R)</translation>
    </message>
    <message>
        <source>E&amp;ntries</source>
        <translation>エントリー(&amp;N)</translation>
    </message>
    <message>
        <source>Copy att&amp;ribute to clipboard</source>
        <translation>クリップボードにコピー(&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Groups</source>
        <translation>グループ(&amp;G)</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>表示(&amp;V)</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>終了(&amp;Q)</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>このソフトウェアについて(&amp;A)</translation>
    </message>
    <message>
        <source>&amp;Save database</source>
        <translation>データベースを保存(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Close database</source>
        <translation>データベースを閉じる(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;New database</source>
        <translation>新しいデータベース(&amp;N)</translation>
    </message>
    <message>
        <source>Merge from KeePassX database</source>
        <translation>KeePassX データベースからマージ</translation>
    </message>
    <message>
        <source>&amp;Add new entry</source>
        <translation>新しいエントリーを追加(&amp;A)</translation>
    </message>
    <message>
        <source>&amp;View/Edit entry</source>
        <translation>エントリーを表示/編集(&amp;V)</translation>
    </message>
    <message>
        <source>&amp;Delete entry</source>
        <translation>エントリーを削除(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Add new group</source>
        <translation>新しいグループを追加(&amp;A)</translation>
    </message>
    <message>
        <source>&amp;Edit group</source>
        <translation>グループを編集(&amp;E)</translation>
    </message>
    <message>
        <source>&amp;Delete group</source>
        <translation>グループを削除(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Database settings</source>
        <translation>データベースの設定(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Clone entry</source>
        <translation>エントリーを複製(&amp;C)</translation>
    </message>
    <message>
        <source>Timed one-time password</source>
        <translation>時限ワンタイムパスワード</translation>
    </message>
    <message>
        <source>Copy &amp;TOTP</source>
        <translation>TOTP をコピー(&amp;T)</translation>
    </message>
    <message>
        <source>Show TOTP</source>
        <translation>TOTP を表示</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>検索(&amp;F)</translation>
    </message>
    <message>
        <source>Copy &amp;username</source>
        <translation>ユーザー名をコピー(&amp;U)</translation>
    </message>
    <message>
        <source>Cop&amp;y password</source>
        <translation>パスワードをコピー(&amp;Y)</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>設定(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Perform Auto-Type</source>
        <translation>自動入力を実行(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Open URL</source>
        <translation>URL を開く(&amp;O)</translation>
    </message>
    <message>
        <source>&amp;Lock databases</source>
        <translation>データベースをロック(&amp;L)</translation>
    </message>
    <message>
        <source>&amp;Title</source>
        <translation>タイトル(&amp;T)</translation>
    </message>
    <message>
        <source>&amp;URL</source>
        <translation>URL(&amp;U)</translation>
    </message>
    <message>
        <source>&amp;Notes</source>
        <translation>メモ(&amp;N)</translation>
    </message>
    <message>
        <source>Password Generator</source>
        <translation>パスワード生成</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>履歴を消去</translation>
    </message>
    <message>
        <source>&amp;Database</source>
        <translation>データベース(&amp;D)</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>インポート</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>ツール(&amp;T)</translation>
    </message>
    <message>
        <source>Empty recycle bin</source>
        <translation>ゴミ箱を空にする</translation>
    </message>
    <message>
        <source>Access error for config file %1</source>
        <translation>設定ファイル %1 へのアクセスエラー</translation>
    </message>
    <message>
        <source>Quit KeePassXC</source>
        <translation>KeePassXC を終了</translation>
    </message>
    <message>
        <source>Please touch the button on your YubiKey!</source>
        <translation>YubiKey のボタンにタッチしてください</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>ヘルプ(&amp;H)</translation>
    </message>
    <message>
        <source>&amp;Open database...</source>
        <translation>データベースを開く(&amp;O)...</translation>
    </message>
    <message>
        <source>Sa&amp;ve database as...</source>
        <translation>データベースを別名で保存(&amp;V)...</translation>
    </message>
    <message>
        <source>Change &amp;master key...</source>
        <translation>マスターキーを変更(&amp;M)...</translation>
    </message>
    <message>
        <source>&amp;Export to CSV file...</source>
        <translation>CSV ファイルへエクスポート(&amp;E)...</translation>
    </message>
    <message>
        <source>Import KeePass 1 database...</source>
        <translation>KeePass 1 データベースをインポート...</translation>
    </message>
    <message>
        <source>Import CSV file...</source>
        <translation>CSV ファイルをインポート...</translation>
    </message>
    <message>
        <source>Re&amp;pair database...</source>
        <translation>データベースを修復(&amp;P)...</translation>
    </message>
    <message>
        <source>Set up TOTP...</source>
        <translation>TOTP の設定...</translation>
    </message>
</context>
<context>
    <name>OptionDialog</name>
    <message>
        <source>Dialog</source>
        <translation>ダイアログ</translation>
    </message>
    <message>
        <source>General</source>
        <translation>一般</translation>
    </message>
    <message>
        <source>Sh&amp;ow a notification when credentials are requested</source>
        <translation>クレデンシャルを要求された際に通知を表示する(&amp;O)</translation>
    </message>
    <message>
        <source>Sort matching entries by &amp;username</source>
        <translation>マッチするエントリーをユーザー名で並べ替える(&amp;U)</translation>
    </message>
    <message>
        <source>Re&amp;move all stored permissions from entries in active database</source>
        <translation>アクティブなデータベースのエントリーに保存されたアクセス許可をすべて削除する(&amp;M)</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>詳細設定</translation>
    </message>
    <message>
        <source>Always allow &amp;access to entries</source>
        <translation>常にエントリーへのアクセスを許可する(&amp;A)</translation>
    </message>
    <message>
        <source>Always allow &amp;updating entries</source>
        <translation>常にエントリーの更新を許可する(&amp;U)</translation>
    </message>
    <message>
        <source>Searc&amp;h in all opened databases for matching entries</source>
        <translation>すべての開かれたデータベースからマッチするエントリーを検索する(&amp;H)</translation>
    </message>
    <message>
        <source>HTTP Port:</source>
        <translation>HTTP ポート:</translation>
    </message>
    <message>
        <source>Default port: 19455</source>
        <translation>デフォルトのポート: 19455</translation>
    </message>
    <message>
        <source>Re&amp;quest to unlock the database if it is locked</source>
        <translation>データベースがロックされている場合はロックの解除を要求する(&amp;Q)</translation>
    </message>
    <message>
        <source>Sort &amp;matching entries by title</source>
        <translation>マッチするエントリーをタイトルで並べ替える(&amp;M)</translation>
    </message>
    <message>
        <source>KeePassXC will listen to this port on 127.0.0.1</source>
        <translation>KeePassXC は 127.0.0.1 のこのポートをリッスンします</translation>
    </message>
    <message>
        <source>Cannot bind to privileged ports</source>
        <translation>特権ポートにバインドできません</translation>
    </message>
    <message>
        <source>Cannot bind to privileged ports below 1024!
Using default port 19455.</source>
        <translation>1024 以下の特権ポートにバインドできません。
デフォルトのポート 19455 を使用します。</translation>
    </message>
    <message>
        <source>R&amp;emove all shared encryption keys from active database</source>
        <translation>アクティブなデータベースから共有暗号化キーをすべて削除する(&amp;E)</translation>
    </message>
    <message>
        <source>&amp;Return advanced string fields which start with &quot;KPH: &quot;</source>
        <translation>&quot;KPH: &quot; から始まる拡張された文字列フィールドを返す(&amp;R)</translation>
    </message>
    <message>
        <source>Automatically creating or updating string fields is not supported.</source>
        <translation>文字列フィールドの自動作成や自動更新はサポートされていません。</translation>
    </message>
    <message>
        <source>This is required for accessing your databases from ChromeIPass or PassIFox</source>
        <translation>このオプションは ChromeIPass や PassIFox からデータベースにアクセスするために必要です</translation>
    </message>
    <message>
        <source>Enable KeePassHTTP server</source>
        <translation>KeePassHTTP サーバーを有効にする</translation>
    </message>
    <message>
        <source>Only returns the best matches for a specific URL instead of all entries for the whole domain.</source>
        <translation>ドメイン全体にマッチするすべてのエントリーの代わりに、特定の URL に最もマッチするエントリーのみが返されます。</translation>
    </message>
    <message>
        <source>&amp;Return only best matching entries</source>
        <translation>最もマッチするエントリーのみを返す(&amp;R)</translation>
    </message>
    <message>
        <source>Only entries with the same scheme (http://, https://, ftp://, ...) are returned.</source>
        <translation>同じスキーム (http://, https://, ftp://, ...) を持つエントリーのみが返されます。</translation>
    </message>
    <message>
        <source>&amp;Match URL schemes</source>
        <translation>URL スキームのマッチ(&amp;M)</translation>
    </message>
    <message>
        <source>Password Generator</source>
        <translation>パスワード生成</translation>
    </message>
    <message>
        <source>Only the selected database has to be connected with a client.</source>
        <translation>選択されたデータベースのみがクライアントと接続する必要があります。</translation>
    </message>
    <message>
        <source>The following options can be dangerous!
Change them only if you know what you are doing.</source>
        <translation>以下は危険なオプションです。
設定の内容を理解している場合にのみ、変更を行ってください。</translation>
    </message>
</context>
<context>
    <name>PasswordGeneratorWidget</name>
    <message>
        <source>Password:</source>
        <translation>パスワード:</translation>
    </message>
    <message>
        <source>Character Types</source>
        <translation>文字種</translation>
    </message>
    <message>
        <source>Upper Case Letters</source>
        <translation>大文字</translation>
    </message>
    <message>
        <source>Lower Case Letters</source>
        <translation>小文字</translation>
    </message>
    <message>
        <source>Numbers</source>
        <translation>数字</translation>
    </message>
    <message>
        <source>Special Characters</source>
        <translation>特殊な文字</translation>
    </message>
    <message>
        <source>Exclude look-alike characters</source>
        <translation>よく似た文字を除外する</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>適用</translation>
    </message>
    <message>
        <source>%p%</source>
        <translation>%p%</translation>
    </message>
    <message>
        <source>strength</source>
        <translation>強度</translation>
    </message>
    <message>
        <source>entropy</source>
        <translation>エントロピー</translation>
    </message>
    <message>
        <source>&amp;Length:</source>
        <translation>長さ(&amp;L):</translation>
    </message>
    <message>
        <source>Pick characters from every group</source>
        <translation>すべての使用する文字種から文字を選ぶ</translation>
    </message>
    <message>
        <source>Generate</source>
        <translation>生成</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>適用</translation>
    </message>
    <message>
        <source>Entropy: %1 bit</source>
        <translation>エントロピー: %1 ビット</translation>
    </message>
    <message>
        <source>Password Quality: %1</source>
        <translation>パスワードの品質: %1</translation>
    </message>
    <message>
        <source>Poor</source>
        <translation>貧弱</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>弱い</translation>
    </message>
    <message>
        <source>Good</source>
        <translation>良い</translation>
    </message>
    <message>
        <source>Excellent</source>
        <translation>すばらしい</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>パスワード</translation>
    </message>
    <message>
        <source>Extended ASCII</source>
        <translation>拡張 ASCII</translation>
    </message>
    <message>
        <source>Passphrase</source>
        <translation>パスフレーズ</translation>
    </message>
    <message>
        <source>Wordlist:</source>
        <translation>単語リスト:</translation>
    </message>
    <message>
        <source>Word Count:</source>
        <translation>単語数:</translation>
    </message>
    <message>
        <source>Word Separator:</source>
        <translation>単語の区切り文字:</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>コピー</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>NULL device</source>
        <translation>NULL デバイス</translation>
    </message>
    <message>
        <source>error reading from device</source>
        <translation>デバイス読み込みエラー</translation>
    </message>
    <message>
        <source>file empty !
</source>
        <translation>空ファイルです</translation>
    </message>
    <message>
        <source>malformed string</source>
        <translation>不正な形式の文字列</translation>
    </message>
    <message>
        <source>missing closing quote</source>
        <translation>閉じ引用符がありません</translation>
    </message>
    <message>
        <source>INTERNAL - unget lower bound exceeded</source>
        <translation>INTERNAL - unget が下限を超過しました</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>グループ</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>タイトル</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>ユーザー名</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>パスワード</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Notes</source>
        <translation>メモ</translation>
    </message>
    <message>
        <source>Browser Integration</source>
        <translation>ブラウザ統合</translation>
    </message>
    <message>
        <source>YubiKey[%1] Challenge Response - Slot %2 - %3</source>
        <translation>YubiKey [%1] のチャレンジレスポンス - スロット %2 - %3</translation>
    </message>
    <message>
        <source>Press</source>
        <translation>Press</translation>
    </message>
    <message>
        <source>Passive</source>
        <translation>Passive</translation>
    </message>
</context>
<context>
    <name>QtIOCompressor</name>
    <message>
        <source>Internal zlib error when compressing: </source>
        <translation>圧縮時に内部 zlib エラーが発生しました: </translation>
    </message>
    <message>
        <source>Error writing to underlying device: </source>
        <translation>基本デバイスへの書き込み時にエラーが発生しました:</translation>
    </message>
    <message>
        <source>Error opening underlying device: </source>
        <translation>基本デバイスを開く時にエラーが発生しました:</translation>
    </message>
    <message>
        <source>Error reading data from underlying device: </source>
        <translation>基本デバイスから読み込み時にエラーが発生しました:</translation>
    </message>
    <message>
        <source>Internal zlib error when decompressing: </source>
        <translation>展開時に内部 zlib エラーが発生しました: </translation>
    </message>
</context>
<context>
    <name>QtIOCompressor::open</name>
    <message>
        <source>The gzip format not supported in this version of zlib.</source>
        <translation>zlib の現在のバージョンが gzip 形式をサポートしていません。</translation>
    </message>
    <message>
        <source>Internal zlib error: </source>
        <translation>内部の zlib エラー:</translation>
    </message>
</context>
<context>
    <name>SearchWidget</name>
    <message>
        <source>Case Sensitive</source>
        <translation>大文字と小文字の区別</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>検索</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>消去</translation>
    </message>
    <message>
        <source>Search...</source>
        <translation>検索...</translation>
    </message>
    <message>
        <source>Limit search to selected group</source>
        <translation>選択したグループに検索対象を制限</translation>
    </message>
</context>
<context>
    <name>Service</name>
    <message>
        <source>A shared encryption-key with the name &quot;%1&quot; already exists.
Do you want to overwrite it?</source>
        <translation>共有暗号化キー &quot;%1&quot; は既に存在します。
上書きしますか？</translation>
    </message>
    <message>
        <source>Do you want to update the information in %1 - %2?</source>
        <translation>%1 - %2 の情報を更新しますか？</translation>
    </message>
    <message>
        <source>The active database is locked!
Please unlock the selected database or choose another one which is unlocked.</source>
        <translation>アクティブなデータベースがロックされています。
選択されたデータベースのロックを解除するか、別のロックされていないデータベースを選択してください。</translation>
    </message>
    <message>
        <source>Successfully removed %1 encryption-%2 from KeePassX/Http Settings.</source>
        <translation>KeePassX/Http の設定から %1 個の暗号化%2が無事に削除されました。</translation>
    </message>
    <message>
        <source>No shared encryption-keys found in KeePassHttp Settings.</source>
        <translation>KeePassHttp の設定内に共有暗号化キーは見つかりませんでした。</translation>
    </message>
    <message>
        <source>The active database does not contain an entry of KeePassHttp Settings.</source>
        <translation>アクティブなデータベースに KeePassHttp の設定のエントリーが含まれていません。</translation>
    </message>
    <message>
        <source>Removing stored permissions...</source>
        <translation>保存されたアクセス許可を削除しています…</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>中止</translation>
    </message>
    <message>
        <source>Successfully removed permissions from %1 %2.</source>
        <translation>%1 個の%2から無事にアクセス許可が削除されました。</translation>
    </message>
    <message>
        <source>The active database does not contain an entry with permissions.</source>
        <translation>アクティブなデータベースにはアクセス許可があるエントリーは含まれていません。</translation>
    </message>
    <message>
        <source>KeePassXC: New key association request</source>
        <translation>KeePassXC: 新しいキーのアソシエーション要求</translation>
    </message>
    <message>
        <source>You have received an association request for the above key.
If you would like to allow it access to your KeePassXC database
give it a unique name to identify and accept it.</source>
        <translation>他のアプリケーションからのアソシエーション要求を受け取りました。
KeePassXC のデータベースへのアクセスを許可したい場合は、
要求元を識別して受け入れるためのユニークな名前を付けてください。</translation>
    </message>
    <message>
        <source>KeePassXC: Overwrite existing key?</source>
        <translation>KeePassXC: 既存のキーを上書きしますか？</translation>
    </message>
    <message>
        <source>KeePassXC: Update Entry</source>
        <translation>KeePassXC: エントリーを更新</translation>
    </message>
    <message>
        <source>KeePassXC: Database locked!</source>
        <translation>KeePassXC: データベースはロックされています</translation>
    </message>
    <message>
        <source>KeePassXC: Removed keys from database</source>
        <translation>KeePassXC: データベースからキーが削除されました</translation>
    </message>
    <message>
        <source>KeePassXC: No keys found</source>
        <translation>KeePassXC: キーが見つかりません</translation>
    </message>
    <message>
        <source>KeePassXC: Settings not available!</source>
        <translation>KeePassXC: 設定は利用できません</translation>
    </message>
    <message>
        <source>KeePassXC: Removed permissions</source>
        <translation>KeePassXC: アクセス許可が削除されました</translation>
    </message>
    <message>
        <source>KeePassXC: No entry with permissions found!</source>
        <translation>KeePassXC: アクセス許可があるエントリーは見つかりません</translation>
    </message>
</context>
<context>
    <name>SettingsWidget</name>
    <message>
        <source>Application Settings</source>
        <translation>アプリケーション設定</translation>
    </message>
    <message>
        <source>General</source>
        <translation>一般</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>セキュリティ</translation>
    </message>
    <message>
        <source>Access error for config file %1</source>
        <translation>設定ファイル %1 へのアクセスエラー</translation>
    </message>
</context>
<context>
    <name>SettingsWidgetGeneral</name>
    <message>
        <source>Remember last databases</source>
        <translation>最近使用したデータベースを記憶する</translation>
    </message>
    <message>
        <source>Automatically save on exit</source>
        <translation>終了時に自動的に保存する</translation>
    </message>
    <message>
        <source>Automatically save after every change</source>
        <translation>変更するたびに自動的に保存する</translation>
    </message>
    <message>
        <source>Minimize when copying to clipboard</source>
        <translation>クリップボードにコピーしたら最小化する</translation>
    </message>
    <message>
        <source>Use group icon on entry creation</source>
        <translation>エントリー作成時にグループのアイコンを使用する</translation>
    </message>
    <message>
        <source>Global Auto-Type shortcut</source>
        <translation>グローバル自動入力のショートカット</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>言語</translation>
    </message>
    <message>
        <source>Show a system tray icon</source>
        <translation>システムトレイアイコンを表示する</translation>
    </message>
    <message>
        <source>Hide window to system tray when minimized</source>
        <translation>最小化された際にシステムトレイへ格納する</translation>
    </message>
    <message>
        <source>Load previous databases on startup</source>
        <translation>起動時に前回のデータベースを読み込む</translation>
    </message>
    <message>
        <source>Automatically reload the database when modified externally</source>
        <translation>編集された際に自動でデータベースを再読み込みする</translation>
    </message>
    <message>
        <source>Hide window to system tray instead of app exit</source>
        <translation>アプリケーション終了ではなくシステムトレイへ格納する</translation>
    </message>
    <message>
        <source>Minimize window at application startup</source>
        <translation>アプリケーション起動時にウィンドウを最小化する</translation>
    </message>
    <message>
        <source>Basic Settings</source>
        <translation>基本設定</translation>
    </message>
    <message>
        <source>Remember last key files and security dongles</source>
        <translation>最近使用したキーファイルとセキュリティードングルを記憶する</translation>
    </message>
    <message>
        <source>Don&apos;t mark database as modified for non-data changes (e.g., expanding groups)</source>
        <translation>データ以外の変更（例えばグループの展開）に対して、データベースを修正済みとしてマークしないようにする</translation>
    </message>
    <message>
        <source>Auto-Type</source>
        <translation>自動入力</translation>
    </message>
    <message>
        <source>Use entry title and URL to match windows for global Auto-Type</source>
        <translation>グローバル自動入力のウィンドウの照合にエントリーのタイトルと URL を使用する</translation>
    </message>
    <message>
        <source>Always ask before performing Auto-Type</source>
        <translation>自動入力を行う前に毎回確認する</translation>
    </message>
    <message>
        <source>Auto-Type delay</source>
        <translation>自動入力の遅延</translation>
    </message>
    <message>
        <source> ms</source>
        <translation>ミリ秒</translation>
    </message>
    <message>
        <source>Start only a single instance of KeePassXC</source>
        <translation>KeePassXC のインスタンスを一つだけ起動する</translation>
    </message>
</context>
<context>
    <name>SettingsWidgetSecurity</name>
    <message>
        <source>Clear clipboard after</source>
        <translation>次の時間が過ぎたらクリップボードを消去</translation>
    </message>
    <message>
        <source> sec</source>
        <translation>秒</translation>
    </message>
    <message>
        <source>Lock databases after inactivity of</source>
        <translation>未操作の時間が続いたらデータベースをロック</translation>
    </message>
    <message>
        <source>Show passwords in cleartext by default</source>
        <translation>パスワードはデフォルトで平文表示にする</translation>
    </message>
    <message>
        <source>Lock databases after minimizing the window</source>
        <translation>ウィンドウを最小化したらデータベースをロックする</translation>
    </message>
    <message>
        <source>Don&apos;t require password repeat when it is visible</source>
        <translation>パスワードが表示されている場合は、パスワードの再入力を必要としないようにする</translation>
    </message>
    <message>
        <source>Timeouts</source>
        <translation>タイムアウト</translation>
    </message>
    <message>
        <source>Convenience</source>
        <translation>利便性</translation>
    </message>
    <message>
        <source>Lock databases when session is locked or lid is closed</source>
        <translation>セッションがロックされたりラップトップが閉じられた際にデータベースをロックする</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>プライバシー</translation>
    </message>
    <message>
        <source>Use Google as fallback for downloading website icons</source>
        <translation>ウェブサイトのアイコンをダウンロードするためのフォールバックとして Google を使用する</translation>
    </message>
</context>
<context>
    <name>SetupTotpDialog</name>
    <message>
        <source>Setup TOTP</source>
        <translation>TOTP の設定</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>キー:</translation>
    </message>
    <message>
        <source>Use custom settings</source>
        <translation>カスタム設定を使用する</translation>
    </message>
    <message>
        <source>Note: Change these settings only if you know what you are doing.</source>
        <translation>注意: 何をしようとしているのか理解している場合にのみ、設定を変更してください。</translation>
    </message>
    <message>
        <source>Time step:</source>
        <translation>タイムステップ:</translation>
    </message>
    <message>
        <source>8 digits</source>
        <translation>8桁</translation>
    </message>
    <message>
        <source>6 digits</source>
        <translation>6桁</translation>
    </message>
    <message>
        <source>Code size:</source>
        <translation>コードサイズ:</translation>
    </message>
    <message>
        <source> sec</source>
        <translation>秒</translation>
    </message>
</context>
<context>
    <name>TotpDialog</name>
    <message>
        <source>Timed Password</source>
        <translation>時限パスワード</translation>
    </message>
    <message>
        <source>000000</source>
        <translation>000000</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>コピー</translation>
    </message>
    <message>
        <source>Expires in</source>
        <translation>期限切れまで</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>秒</translation>
    </message>
</context>
<context>
    <name>UnlockDatabaseWidget</name>
    <message>
        <source>Unlock database</source>
        <translation>データベースのロックを解除</translation>
    </message>
</context>
<context>
    <name>WelcomeWidget</name>
    <message>
        <source>Welcome to KeePassXC</source>
        <translation>KeePassXC へようこそ</translation>
    </message>
    <message>
        <source>Start storing your passwords securely in a KeePassXC database</source>
        <translation>KeePassXC データベースに安全にパスワードを保管する</translation>
    </message>
    <message>
        <source>Create new database</source>
        <translation>新しいデータベースを作成する</translation>
    </message>
    <message>
        <source>Open existing database</source>
        <translation>既存のデータベースを開く</translation>
    </message>
    <message>
        <source>Import from KeePass 1</source>
        <translation>KeePass 1 からインポートする</translation>
    </message>
    <message>
        <source>Import from CSV</source>
        <translation>CSV からインポートする</translation>
    </message>
    <message>
        <source>Recent databases</source>
        <translation>最近使用したデータベース</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>path to a custom config file</source>
        <translation>カスタム設定ファイルへのパス</translation>
    </message>
    <message>
        <source>key file of the database</source>
        <translation>データベースのキーファイル</translation>
    </message>
    <message>
        <source>KeePassXC - cross-platform password manager</source>
        <translation>KeePassXC - クロスプラットフォームのパスワードマネージャー</translation>
    </message>
    <message>
        <source>read password of the database from stdin</source>
        <translation>標準入力からデータベースのパスワードを読み込む</translation>
    </message>
    <message>
        <source>filenames of the password databases to open (*.kdbx)</source>
        <translation>開くパスワードデータベースのファイル名 (*.kdbx)</translation>
    </message>
    <message>
        <source>Copy a password to the clipboard</source>
        <translation>クリップボードにパスワードをコピーする</translation>
    </message>
    <message>
        <source>Path of the database.</source>
        <translation>データベースのパス。</translation>
    </message>
    <message>
        <source>Use a GUI prompt unlocking the database.</source>
        <translation>データベースのロックを解除する際に GUI プロンプトを使用する。</translation>
    </message>
    <message>
        <source>Name of the entry to clip.</source>
        <translation>クリップするエントリーの名前。</translation>
    </message>
    <message>
        <source>Extract and print the content of a database.</source>
        <translation>データベースの内容を展開して出力する。</translation>
    </message>
    <message>
        <source>Path of the database to extract.</source>
        <translation>展開するデータベースのパス。</translation>
    </message>
    <message>
        <source>Name of the command to execute.</source>
        <translation>実行するコマンドの名前。</translation>
    </message>
    <message>
        <source>List database entries.</source>
        <translation>データベースのエントリーのリストを表示する。</translation>
    </message>
    <message>
        <source>Path of the group to list. Default is /</source>
        <translation>リストを表示するグループのパス。デフォルトは / (ルート)</translation>
    </message>
    <message>
        <source>Print the UUIDs of the entries and groups.</source>
        <translation>エントリーとグループの UUID を出力する。</translation>
    </message>
    <message>
        <source>Merge two databases.</source>
        <translation>2つのデータベースをマージする。</translation>
    </message>
    <message>
        <source>Path of the database to merge into.</source>
        <translation>マージ先のデータベースのパス。</translation>
    </message>
    <message>
        <source>Path of the database to merge from.</source>
        <translation>マージ元のデータベースのパス。</translation>
    </message>
    <message>
        <source>Use the same password for both database files.</source>
        <translation>両方のデータベースファイルに対して同一のパスワードを使用する。</translation>
    </message>
    <message>
        <source>Show a password.</source>
        <translation>パスワードを表示する。</translation>
    </message>
    <message>
        <source>Name of the entry to show.</source>
        <translation>表示するエントリーの名前。</translation>
    </message>
</context>
</TS>